% Example script for loading OH14 data using OH14_loadmap.m MATLAB script

lon_W = 143; % 148 degrees East
lon_E = 150; % 149 degrees East
lat_S = -44.5; % 44 degrees South
lat_N = -37.5; % 43 degrees South

date_start = [1993 4 1]; % 1 April 1993
date_end = [2001 11 31]; % 31 November 2001

path_to_OH14_nc = '../data/OH14.nc'; % path to OH14 NetCDF file, in this case it lies in the working directory

[time, lon, lat, T, T_sige, T_mean, T_seas, T_seas_sige, T_res, T_res_sige] = OH14_loadmap(date_start, date_end, lon_W, lon_E, lat_S, lat_N, path_to_OH14_nc);

% If you are using an older version of Matlab which does not have
% the built-in NetCDF API (at least v2010a and earlier, possibly
% v2012a and earlier) then you can call OH14_loadmap as follows:
% [time, lon, lat, T, T_sige, T_mean, T_seas, T_seas_sige, T_res, T_res_sige] = OH14_loadmap(date_start, date_end, lon_W, lon_E, lat_S, lat_N, path_to_OH14_nc, 'netcdf_toolbox', '../lib/netcdf_toolbox/');
% Note the two added options which specify the netcdf_toolbox
% which is provided in the lib/netcdf_toolbox/ folder.

% Map mean SST
figure;
pcolor(lon, lat, T_mean);
shading flat;
colorbar;
grid;
% export_fig -pdf /home/ecoliver/Desktop/ssf/documents/04_Linear_Stat_Downscale_Model/OH14_manual/figures/mean_sst.pdf

% SST on 10 April 1993 (date_start + 9 days = time step #10)
figure;
pcolor(lon, lat, squeeze(T(10,:,:)));
shading flat;
colorbar;
grid;
% export_fig -pdf /home/ecoliver/Desktop/ssf/documents/04_Linear_Stat_Downscale_Model/OH14_manual/figures/sst_10apr1993.pdf

% Time series of SST
i = find(lon>146, 1, 'first');
j = find(lat>-40, 1, 'first');
figure;
plot(time, T(:,j,i), 'b-', 'linewidth', 2);
hold on;
plot(time, T(:,j,i) + T_sige(j,i), 'k-');
plot(time, T(:,j,i) - T_sige(j,i), 'k-');
datetick('x', 10)
grid;
% export_fig -pdf /home/ecoliver/Desktop/ssf/documents/04_Linear_Stat_Downscale_Model/OH14_manual/figures/ts_146E_40S.pdf
